@@ -6,7 +6,9 @@ from pathlib import Path
 from .config import navigatorConfig
 config = navigatorConfig()
 
-DEBUG = os.getenv('DEBUG', False)
+DEBUG = bool(config.getboolean('DEBUG'))
+print('DEBUG: ', DEBUG)
+
 BASE_DIR = Path(os.getenv('BASE_DIR', config.site_root)).resolve()
 SETTINGS_DIR = BASE_DIR.joinpath('settings')
 print('SETTINGS PATH: ', SETTINGS_DIR)
@@ -17,6 +19,11 @@ if str(BASE_DIR) not in sys.path:
 if str(SETTINGS_DIR) not in sys.path:
     sys.path.append(str(SETTINGS_DIR))
 
+# CACHE INFO
+CACHE_HOST = config.get('CACHEHOST', fallback='localhost')
+CACHE_PORT = config.get('CACHEPORT', fallback=6379)
+CACHE_URL = "redis://{}:{}".format(CACHE_HOST, CACHE_PORT)
+
 try:
     from settings.settings import *
 except (ImportError, ModuleNotFoundError) as err:
